"use client"
import React, { useState, useEffect } from 'react';
import { useSearchParams } from 'next/navigation';
import axios from '@/services/APIservices';
import NeedHelp from '@/components/postproperty/NeedHelp';
import Amenities from '@/components/property/Amenities';
import DeveloperAmenities from '@/components/property/developerAmenities';
import BasicDetails from '@/components/property/BasicDetails';
import ContactFrom from '@/components/property/ContactFrom';
import LocationDetails from '@/components/property/LocationDetails';
import DeveloperProjectDetails from '@/components/property/DeveloperProjectDetails';
import MapAndImages from '@/components/property/MapAndImages';
import Overview from '@/components/property/Overview';
import VideosAndDocs from '@/components/property/VideosAndDocs';
import AddReview from '@/components/property/AddReview';
import Footer from '@/components/universal/Footer';
import Header from '@/components/universal/Header';
import MobileNavbar from '@/components/universal/MobileNavbar';

const Page = () => {
  const [selectedNav, setSelectedNav] = useState("Overview"); 
  const [propertyDetails, setPropertyDetails] = useState(null);
  const [developerPostDetails, setDeveloperPostDetails] = useState(null);
  const [postUserName, setPostUserName] = useState(null); 
  const [postUserPhoto, setPostUserPhoto] = useState(null); 
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState(null);
  const searchParams = useSearchParams();
  const postId = searchParams.get('postId');

  const fetchPropertyDetails = async () => {
    if (!postId) {
      setError('No Property ID provided');
      setIsLoading(false);
      return;
    }

    try {
      const response = await axios.get(`/api/post-details/${postId}`);
      
      if (response.data && response.data.success) {
        setPropertyDetails(response.data.livePostDetails?.[0] || null);
        setPostUserName(response.data.username || null);
        setPostUserPhoto(response.data.profilePhoto || null);  
        setDeveloperPostDetails(response.data.developerPostDetails?.[0] || null);
        setError(null);
      } else {
        throw new Error('Failed to fetch property details');
      }
    } catch (err) {
      setError(err.message);
      console.error('Error fetching property details:', err);
    } finally {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    fetchPropertyDetails();

    const interval = setInterval(() => {
      fetchPropertyDetails();
    }, 5000);

    return () => clearInterval(interval);
  }, [postId]);

  // Helper function to check if Amenities can be rendered
  const canRenderAmenities = () => {
    return (
      propertyDetails?.land_price?.[0]?.basic_req &&
      propertyDetails?.land_distance?.[0]?.road_touch &&
      propertyDetails?.land_distance?.[0]?.plot_facing
    );
  };

  if (isLoading && !propertyDetails) {
    return (
      <div className='flex justify-center items-center min-h-screen bg-[#e0e0e0]'>
        <div className='animate-spin rounded-full h-16 w-16 border-t-4 border-blue-500'></div>
      </div>
    );
  }

  if (error && !propertyDetails) {
    return (
      <div className='flex justify-center items-center min-h-screen bg-[#e0e0e0] p-4'>
        <div className='bg-white p-8 rounded-lg shadow-md text-center'>
          <h2 className='text-2xl font-bold text-red-600 mb-4'>Error</h2>
          <p className='text-gray-700'>{error}</p>
        </div>
      </div>
    );
  }

  if (!propertyDetails) {
    return (
      <div className='flex justify-center items-center min-h-screen bg-[#e0e0e0] p-4'>
        <p className='text-gray-700'>No property details available.</p>
      </div>
    );
  }

  return (
    <div className='bg-[#e0e0e0] lg:min-h-[100vh]'>
      <Header />
      <MobileNavbar />
      <div className='lg:px-32 px-4 my-8 flex flex-col gap-8'>
        <BasicDetails
          propertyTitle={propertyDetails.land_type || ''}  
          propertyCity={propertyDetails.land_distance[0]?.city || ''}
          postBy={propertyDetails.user_role}
          propertySize={`${propertyDetails.land_size} ${propertyDetails.land_size_unit}`}
          postDate={new Date(propertyDetails.created_at).toLocaleDateString()}
          price={propertyDetails.land_price[0]?.price}
          pricePerUnit={propertyDetails.land_price[0]?.per_unit}
          developerPostPrice={developerPostDetails?.developer_project_amenities?.[0]?.price}
          developerPostPriceUnit={developerPostDetails?.developer_project_amenities?.[0]?.price_unit}
        />

        <MapAndImages
          selectedNav={selectedNav}
          setSelectedNav={setSelectedNav}
          mainImg={propertyDetails.land_photos?.[0]?.main_img || ''}
          thumbImages={
            propertyDetails.land_photos?.[0]?.thumbnails?.map(
              (thumb) => thumb.thumb_photos
            ) || []
          }
        />
      </div>

      <div className="flex lg:flex-row flex-col justify-between lg:px-32 px-4 gap-8 pb-8">
        <div className='lg:w-2/3 w-full'>
          {selectedNav === "Overview" && (
            <>
              <Overview 
                propertySize={`${propertyDetails.land_size} ${propertyDetails.land_size_unit}`}
                propertyType={propertyDetails.post_type || ''}
                propertyDimension={propertyDetails.dimension}
                price={propertyDetails.land_price[0]?.price}
                developerPostPrice={developerPostDetails?.developer_project_amenities?.[0]?.price}
                developerRERAno={developerPostDetails?.developer_project_details?.[0]?.RERA_no}
                developerPostType={developerPostDetails?.developer_project_details?.[0]?.land_type || ''}  
              />
              <AddReview 
                postId={postId}
                userId={propertyDetails.user_id}
              />
            </>
          )}

          {selectedNav === "Location" && (
            <>
              {(!propertyDetails?.land_distance?.[0]?.distance_form?.airport &&
                !propertyDetails?.land_distance?.[0]?.distance_form?.railway &&
                !propertyDetails?.land_distance?.[0]?.distance_form?.bus_stand &&
                !propertyDetails?.land_distance?.[0]?.distance_form?.hospital &&
                !propertyDetails?.land_distance?.[0]?.distance_form?.school) ? (
                <DeveloperProjectDetails 
                  developerName={developerPostDetails?.developer_project_details?.[0]?.developer_name || 'Unknown Developer'}
                  developerAddress={developerPostDetails?.land_distance?.[0]?.address || 'Address Not Available'}
                  developerTotalProject={developerPostDetails?.developer_project_amenities?.[0]?.plot_number || 'Number Not Available'}
                  projects={[
                    {
                      name: developerPostDetails?.developer_project_details?.[0]?.project_name || 'Unnamed Project',
                      description: developerPostDetails?.developer_project_details?.[0]?.project_description || 'No description available'
                    }
                  ]}
                />
              ) : (
                <LocationDetails
                  distanceAirport={propertyDetails?.land_distance?.[0]?.distance_form?.airport || ''}
                  distanceRailway={propertyDetails?.land_distance?.[0]?.distance_form?.railway || ''}
                  distanceBusstand={propertyDetails?.land_distance?.[0]?.distance_form?.bus_stand || ''}
                  distanceHospital={propertyDetails?.land_distance?.[0]?.distance_form?.hospital || ''}
                  distanceSchool={propertyDetails?.land_distance?.[0]?.distance_form?.school || ''}
                  propertyAddress={propertyDetails?.land_distance?.[0]?.address || ''}
                />
              )}
            </>
          )}

          {selectedNav === "Amenities" && (
            canRenderAmenities() ? (
              <Amenities 
                basicReq={propertyDetails.land_price[0].basic_req || ''}
                propertyRoad={propertyDetails.land_distance[0].road_touch || ''}
                propertyFacing={propertyDetails.land_distance[0].plot_facing || ''}
              />
            ) : (
              <DeveloperAmenities
                developerAmenities={developerPostDetails?.developer_project_amenities?.[0]?.project_amenity || 'No amenities available'}
              />
            )
          )}

          {selectedNav === "Video & Documents" && (
            <VideosAndDocs
              propertyYoutube={propertyDetails.land_photos[0].youtube_link || ''}
            />
          )}
        </div>
        
        <div className='lg:flex-grow flex flex-col gap-4 w-full lg:w-auto'>
          <ContactFrom 
            userID={propertyDetails.user_id}
            postId={postId} 
            postUserName={postUserName}
            postUserPhoto={postUserPhoto}
            postBy={propertyDetails.user_role}
            propertyTitle={propertyDetails.land_type || ''}  
            propertyCity={propertyDetails.land_distance?.[0]?.city || ''}
            price={propertyDetails.land_price[0]?.price}
            mainImg={propertyDetails.land_photos?.[0]?.main_img || ''} 
            developerPostPrice={developerPostDetails?.developer_project_amenities?.[0]?.price}
          />
          <NeedHelp />
        </div>
      </div>
      
      <Footer />
    </div>
  );
};

export default Page;